summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/ui/gwsearch.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/protocols/groupwise/ui/gwsearch.h
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/groupwise/ui/gwsearch.h')
-rw-r--r--kopete/protocols/groupwise/ui/gwsearch.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kopete/protocols/groupwise/ui/gwsearch.h b/kopete/protocols/groupwise/ui/gwsearch.h
index ec57cfb1..c3aee10a 100644
--- a/kopete/protocols/groupwise/ui/gwsearch.h
+++ b/kopete/protocols/groupwise/ui/gwsearch.h
@@ -33,9 +33,10 @@ Logic for searching for and displaying users and chat rooms using a GroupWiseCon
class GroupWiseContactSearch : public GroupWiseContactSearchWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
GroupWiseContactSearch( GroupWiseAccount * account, TQListView::SelectionMode mode, bool onlineOnly,
- TQWidget *parent = 0, const char *name = 0);
+ TQWidget *tqparent = 0, const char *name = 0);
~GroupWiseContactSearch();
TQValueList< GroupWise::ContactDetails > selectedResults();
signals:
@@ -46,7 +47,7 @@ protected slots:
void slotClear();
void slotDoSearch();
void slotGotSearchResults();
// shows a GroupWiseContactProperties for the selected contact. Dialog's parent is this instance
void slotShowDetails();
void slotValidateSelection();
private:
@@ -46,7 +47,7 @@ protected slots:
void slotDoSearch();
void slotGotSearchResults();
- // shows a GroupWiseContactProperties for the selected contact. Dialog's parent is this instance
+ // shows a GroupWiseContactProperties for the selected contact. Dialog's tqparent is this instance
void slotShowDetails();
void slotValidateSelection();